@@ -9,7 +9,7 @@ use Locale::TextDomain::UTF8 'Perinci-To-Doc';
 extends 'Perinci::To::PackageBase';
 with    'SHARYANTO::Role::Doc::Section::AddTextLines';
 
-our $VERSION = '0.42'; # VERSION
+our $VERSION = '0.43'; # VERSION
 
 sub BUILD {
     my ($self, $args) = @_;
@@ -105,7 +105,7 @@ Perinci::To::Text - Generate text documentation for a package from Rinci metadat
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -114,13 +114,9 @@ version 0.42
      name=>'Foo::Bar', meta => {...}, child_metas=>{...});
  say $doc->gen_doc;
 
-You can also try the L<peri-pkg-doc> script (included in the L<Perinci::To::POD>
-distribution) with the C<--format text> option:
+You can also try the L<peri-doc> script with the C<--format text> option:
 
- % peri-pkg-doc --format text /Some/Module/
-
-To generate documentation for a single function, see L<Perinci::Sub::To::Text>
-or the provided command-line script L<peri-func-doc>.
+ % peri-doc --format text /Some/Module/
 
 To generate a usage-like help message for a single function, you can try the
 L<peri-func-usage> from the L<Perinci::CmdLine> distribution.
